<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}


/**
 * Get size information for all currently-registered image sizes.
 *
 * @global $_wp_additional_image_sizes
 * @uses   get_intermediate_image_sizes()
 * @return array $sizes Data for all currently-registered image sizes.
 */
function svi_get_image_sizes()
{
    global $_wp_additional_image_sizes;

    $sizes = array(
        'woocommerce_thumbnail', 'woocommerce_single', 'woocommerce_gallery_thumbnail', 'shop_catalog', 'shop_single', 'shop_thumbnail', 'full',
    );

    foreach (get_intermediate_image_sizes() as $_size) {
        if (in_array($_size, array('thumbnail', 'medium', 'medium_large', 'large'))) {
            array_push($sizes, $_size);
        } elseif (isset($_wp_additional_image_sizes[$_size])) {
            array_push($sizes, $_size);
        }
    }

    $available_sizes = array();
    foreach ($sizes as $size) {
        $available_sizes[$size] = $size;
    }

    return $available_sizes;
}

// This is your option name where all the Redux data is stored.
$opt_name = "woosvi_options";

$args = array(
    'opt_name' => 'woosvi_options',
    'use_cdn' => true,
    'dev_mode' => false,
    'forced_dev_mode_off' => false,
    'display_name' =>  'Smart Variations Images & Swatches',
    'display_version' => SMART_VARIATIONS_IMAGES_VERSION,
    'page_slug' => 'woocommerce_svi',
    'page_title' => 'Smart Variations Images & Swatches for WooCommerce',
    'update_notice' => true,
    'admin_bar' => true,
    'menu_type' => 'submenu',
    'allow_sub_menu' => true,
    'menu_title' => 'SVI',
    'page_parent' => 'woocommerce',
    'customizer' => false,
    'default_mark' => '*',
    'hints' => array(
        'icon' => 'el el-adjust-alt',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'light',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'duration' => '500',
                'event' => 'mouseleave unfocus',
            ),
        ),
    ),
    'output_tag' => true,
    'cdn_check_time' => '1440',
    'page_permissions' => 'edit_products',
    'save_defaults' => true,
    'database' => 'options',
    'transient_time' => '3600',
    'network_sites' => true,
);

Redux::setArgs($opt_name, $args);

$variation_thumbdesc = __('<b>Free Version limited to display 1 image, upgrade to PRO to display all.</b> Unlock all these features <a href="/wp-admin/admin.php?page=woocommerce_svi-pricing" target="_blank">here</a>.<br><br>This option will display the product variations images under the dropdowns/swatches of the product page.<br>All images or Images with no variations assigned will be displayed as default gallery under the main image.<br>Adds lightbox option to be activated or not on this images. <b>Thumbnails Keep visible</b> option should be set disabled because activating this options alraedy keeps the images visible.', 'wc_svi');


Redux::setSection(
    $opt_name,
    array(
        'title' => __('Global', 'wc_svi'),
        'id' => 'general-section',
        //'desc' => __('General settings', 'wc_svi'),
        'icon' => 'el el-home',
        'fields' => array(
            array(
                'id' => 'default',
                'type' => 'switch',
                'title' => __('Enable SVI', 'wc_svi'),
                'desc' => __('Activate or Deactivate SVI from running on your site.', 'wc_svi'),
                'on' => __('Enable', 'wc_svi'),
                'off' => __('Deactivate', 'wc_svi'),
                'default' => true,
            ),
            array(
                'id' => 'default_swatches',
                'type' => 'switch',
                'title' => __('Enable Swacthes', 'wc_svi'),
                'desc' => __('Activate or Deactivate SVI Swacthes from running on your site.', 'wc_svi'),
                'on' => __('Enable', 'wc_svi'),
                'off' => __('Deactivate', 'wc_svi'),
                'default' => false,
            ),
            array(
                'id' => 'variation_thumbnails',
                'type' => 'switch',
                'required' => array(
                    array('default', '=', '1'),
                ),
                'title' => __('Showcase Images under Variations', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => $variation_thumbdesc,
                'default' => false,
            ),
            array(
                'id' => 'notice1',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Showcase Thumbnail Items [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('Number of thumbnails to be displayed by row, min:1 | max: 10.', 'wc_svi'),
                //'validate' => 'numeric',
                'class' => 'svisubfield',
            ),
            array(
                'id' => 'notice2',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Disable SVI display [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => 'Disable SVI from running on products that have no SVI data configurated and fallback to default theme display. <b>Note</b>: I you wish to disable for a specific product visit the product Advanced Tab where you find the option to Disable SVI for that specific product.',
            ),

        ),
    )
);

Redux::setSection(
    $opt_name,
    array(
        'title' => __('Variation Select Form', 'wc_svi'),
        'id' => 'general-subsection-variations',
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'notice3',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Trigger on attribute change [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('All attributes/swacthes will trigger the image changing. Don\'t have to wait for all attributes/swacthes to be selected.', 'wc_svi'),
            ),
            array(
                'id' => 'notice4',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Trigger Exact SVI Gallery Match [PRO VERSION]', 'wc_svi'),
                'subtitle' => __('Only activate if you understand the effect', 'wc_svi'),
                'desc' => __('Variation images will be triggered/displayed according to SVI Galleries created.', 'wc_svi'),
            ),
        ),
    )
);
Redux::setSection(
    $opt_name,
    array(
        'title' => __('Product Loop', 'wc_svi'),
        'id' => 'general-subsection-loopvariations',
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'loop_showcase',
                'type' => 'switch',
                'required' => array('default', '=', '1'),
                'title' => __('Showcase Variations', 'wc_svi'),
                'subtitle' => __('Showcase your variations on the product loop page', 'wc_svi'),
                'desc' => __('Activating this option will showcase the <b>first image</b> of each of your <u>SVI Variations Gallery</u> under each product on the Product loop pages. <b>Free Version limited to 2 Galleries</b><br>You may enable/disable specific galleries from being displayed by checking the proper <u>SVI Variations Gallery</u> on the product.', 'wc_svi'),

                'default' => false,
            ),
            array(
                'id' => 'notice5',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Visible galleries [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('Define a limite of galleries to be displayed p/product, 0 = all', 'wc_svi'),
                'class' => 'svisubfield',
            ),
            array(
                'id' => 'notice6',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Showcase Postion [PRO VERSION]', 'wc_svi'),
                'subtitle' => __('Adjust the position of the showcase in the product loop.', 'wc_svi'),
                'desc' => __('WooCommerce has hooks set in place to allow users to customize the positions of certain elements, if your theme has this hooks in place you may adjust the position.', 'wc_svi'),
            ),
            array(
                'id' => 'notice7',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Showcase Postion Priority [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('Used to specify the order in which the Showcase Postion action will be executed. Lower numbers correspond with earlier execution, and functions with the same priority are executed in the order in which they were added to the action.
                    Default value: 10', 'wc_svi'),
            ),
            array(
                'id' => 'notice8',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Specify Product Wrapper [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('Used to specify the element that if wrapping the product on the loop page. By default is set to find the closest ".product" but just in case your theme doesnt have the class present this option will allow you to define the target. You can specify for example any element (div,li), classes (.product) or both (div.product).', 'wc_svi'),
            ),
            array(
                'id' => 'notice9',
                'type' => 'info',
                'style' => 'warning',
                'title' => __('Specify Product Wrapper Image [PRO VERSION]', 'wc_svi'),
                //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
                'desc' => __('Used to specify the element that if wrapping the product image on the loop page. By default is set to find the first image but just in case the first image is not the product image this option will allow you to define the target. You can specify for example any element (img,div), classes (.attachment-woocommerce_thumbnail) or both (img.attachment-woocommerce_thumbnail).', 'wc_svi'),
            ),
        ),
    )
);
Redux::setSection($opt_name, array(
    'title' => __('Checkout', 'wc_svi'),
    'id' => 'general-subsection-checkout',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'notice10',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Cart Image [PRO VERSION]', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('Display choosen variation image in cart/checkout instead of default Product image.', 'wc_svi'),
        ),
    ),
));

$lists_qv = array(
    'WPC Smart Quick View for WooCommerce' => '.thumbnails-ori'
);
$li_qv = '<ul>';
foreach ($lists_qv as $plugin => $value) {
    $li_qv = '<li>' . $plugin . ': <b>' . $value . '</b></li>';
}
$li_qv .= "</ul>";
Redux::setSection($opt_name, array(
    'title' => __('Images', 'wc_svi'),
    'id' => 'general-subsection-sizes',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'notice11',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Use Feat. Image as Preload [PRO VERSION]', 'wc_svi'),
            'desc' => __('Featured image will be used as preloader until SVI get fully loaded.', 'wc_svi'),
        ),
        array(
            'id' => 'notice90',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Use Placeholder [PRO VERSION]', 'wc_svi'),
            'desc' => __('If activated a placeholder will be displayed for variations that dont have a SVI gallery created otherwise it will fallback to show Default SVI gallery or all images. Want to set a custom placeholder image read <a href="https://docs.woocommerce.com/document/change-the-placeholder-image/" target="_blank">this</a>.', 'wc_svi'),
        ),
        array(
            'id' => 'notice12',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Image Caption [PRO VERSION]', 'wc_svi'),
            'desc' => __('Show Image Title or Caption under main image.<br>Activating this option may require some styling adjustments specific for your theme not supported by this plugin.', 'wc_svi'),
        ),
        array(
            'id' => 'notice13',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Title or Caption [PRO VERSION]', 'wc_svi'),

        ),
        array(
            'id' => 'notice14',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Thumbnails Image Caption [PRO VERSION]', 'wc_svi'),
            'desc' => __('Show Image Title or Caption under thumbnail image.<br>Activating this option may require some styling adjustments specific for your theme not supported by this plugin.', 'wc_svi'),
        ),
        array(
            'id' => 'notice15',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Thumbnails Show Title or Caption [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice16',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Image in Email [PRO VERSION]', 'wc_svi'),
            'desc' => __('Display choosen variation image in order email.', 'wc_svi'),
        ),
        array(
            'id' => 'notice17',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Image in Admin Edit Order [PRO VERSION]', 'wc_svi'),
            'desc' => __('Display choosen variation image in the admin edit order page.', 'wc_svi'),
        ),
        array(
            'id' => 'notice18',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Image in order details [PRO VERSION]', 'wc_svi'),
            'desc' => __('Display choosen variation image in the order details page after the checkout.', 'wc_svi'),
        ),

        array(
            'title' => __('Main Image Size', 'wc_svi'),
            //'subtitle' => __('Select your navigation color', 'wc_svi'),
            'desc' => __('Select your main image size from the registred sizes', 'wc_svi'),
            'id' => 'main_imagesize',
            'default' => 'shop_single',
            'type' => 'select',
            'options' => svi_get_image_sizes(),
        ),
        array(
            'title' => __('Thumbnail Image Size', 'wc_svi'),
            //'subtitle' => __('Select your navigation color', 'wc_svi'),
            'desc' => __('Select your Thumbnail size from the registred sizes', 'wc_svi'),
            'id' => 'thumb_imagesize',
            'default' => 'shop_thumbnail',
            'type' => 'select',
            'options' => svi_get_image_sizes(),
        ),
        array(
            'id' => 'notice19',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Enable Quick View append [PRO VERSION]', 'wc_svi'),
            'desc' => __('If theme has Quick View, SVI <b><u>will try</u></b> to append to it, SVI does not guarantee 100% compatibility.<br>This is a "HACK" so if not compatible or not working get in touch.<br><b>NOTE</b>: Activating this option does not enable Quick View on your site.', 'wc_svi'),
        ),
        array(
            'id' => 'notice20',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Target Quick View Gallery [PRO VERSION]', 'wc_svi'),
            'desc' => __('<p>There are several Quick View solutions from themes/plugins if activating Quick View isnt enough you may target the Quick View Class/ID (The element that contains the WooCommerce gallery). SVI will try to capture and replace it with SVI gallery.</p>', 'wc_svi'),
        ),
        array(
            'id' => 'sviesrcset',
            'type' => 'switch',
            'required' => array('default', '=', '1'),
            'title' => __('Show SRCSET', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('Add scrset attribute to images', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'svititleattr',
            'type' => 'switch',
            'required' => array('default', '=', '1'),
            'title' => __('Show Title attribute', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('Add title attribute to images', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'sviproglobal',
            'type' => 'info',
            'required' => array('default', '=', '1'),
            'title' => __('SVI GLOBAL position display', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('Whether to display SVI GLOBAL images at Beginning or End of other variation images. Default: End', 'wc_svi'),
        ),
    ),
));
/** Stacked */
Redux::setSection($opt_name, array(
    'title' => __('Stacked layout', 'wc_svi'),
    'id' => 'stacked-svi',
    'fields' => array(
        array(
            'id' => 'notice21',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Activate stacked images [PRO VERSION]', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('All images will be showed in a single column, stacked. Only in desktop mode, mobile will fallback to default settings.', 'wc_svi'),
        ),
        array(
            'id' => 'notice22',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Items per row [PRO VERSION]', 'wc_svi'),
            'desc' => __('Number of thumbnails to be displayed by row, min:1 | max: 10.', 'wc_svi'),
        ),
        array(
            'id' => 'notice23',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Force Stacked on Mobile [PRO VERSION]', 'wc_svi'),
            'desc' => __('If activated Stacked layout will also be displayed on mobile otherwise it will fallback to default SVI settings.', 'wc_svi'),
        ),
        array(
            'id' => 'notice24',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Sticky Product Summary [PRO VERSION]', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            'desc' => __('Product Summary will slide side by side with the images until it reaches last image', 'wc_svi'),
        ),
        array(
            'id' => 'notice25',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Sticky Element [PRO VERSION]', 'wc_svi'),
            'desc' => __('The element that needs to be sticky once you scroll. This can be your menu, or any other element like a sidebar, ad banner, etc. Make sure this is a unique identifier.', 'wc_svi'),
        ),
        array(
            'id' => 'notice26',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Margin top [PRO VERSION]', 'wc_svi'),
            'desc' => __('Space between top of page and sticky element: (optional)', 'wc_svi'),
        ),
        array(
            'id' => 'notice27',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Push-up element [PRO VERSION]', 'wc_svi'),
            'desc' => __('If you want your sticky element to be \'pushed up\' again by another element lower on the page, enter it here. Make sure this is a unique identifier.', 'wc_svi'),
        ),
    ),
));
/** Lightbox */
Redux::setSection($opt_name, array(
    'title' => __('Lightbox', 'wc_svi'),
    'id' => 'lightbox-svi',
    'fields' => array(
        array(
            'id' => 'lightbox',
            'type' => 'switch',
            'required' => array(
                array('default', '=', '1'),
            ),
            'title' => __('Activate Lightbox', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            //'desc' => __('Items set with a fold to this ID will hide unless this is set to the appropriate value.', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'notice28',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Activate Lightbox on Images under Variations [PRO VERSION]', 'wc_svi'),
            'desc' => __('This option will display the product variations images under the dropdowns/swatches of the product page.<br>Images with no variations assigned will be displayed as default gallery under the main image.', 'wc_svi'),
        ),
        array(
            'id' => 'lightbox_icon',
            'type' => 'switch',
            'required' => array(
                array('default', '=', '1'),
                array('lightbox', '=', '1'),
            ),
            'title' => __('Show Icon', 'wc_svi'),
            'desc' => __('Enable click icon on image for ligthbox.', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'notice29',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Enable Icon Click [PRO VERSION]', 'wc_svi'),
            'desc' => __('Ligthbox only available on icon click, disables ligthbox on image click.', 'wc_svi'),
        ),
        array(
            'id' => 'notice30',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Icon Color [PRO VERSION]', 'wc_svi'),
            'desc' => __('Pick a color for the icon.', 'wc_svi'),
        ),
        array(
            'id' => 'notice31',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Thumbnails [PRO VERSION]', 'wc_svi'),
            'desc' => __('Display thumbnails inside ligthbox', 'wc_svi'),
        ),
        array(
            'id' => 'lightbox_close',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),
            ),
            'title' => __('Show Close Button', 'wc_svi'),
            'default' => true,
        ),
        array(
            'id' => 'notice32',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Show Image Titles [PRO VERSION]', 'wc_svi'),
            'desc' => __('Display image titles inside the ligthbox', 'wc_svi'),
        ),
        array(
            'id' => 'lightbox_fullScreen',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),

            ),
            'title' => __('Show FullScreen Option', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'lightbox_zoom',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),

            ),
            'title' => __('Show Zoom Option', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'lightbox_share',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),

            ),
            'title' => __('Show Share Option', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'lightbox_counter',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),

            ),
            'title' => __('Show Counter Option', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'lightbox_controls',
            'type' => 'switch',
            'required' => array(
                array('lightbox', '=', '1'),
            ),
            'title' => __('Show Arrows Option', 'wc_svi'),
            'default' => true,
        ),
    ),
));
/** SLIDER SECTION */
Redux::setSection($opt_name, array(
    'title' => __('Slider', 'wc_svi'),
    'id' => 'slider-subsection',
    'fields' => array(
        array(
            'id' => 'slider',
            'type' => 'switch',
            'required' => array(
                array('default', '=', '1'),
            ),
            'title' => __('Activate Slider', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'notice33',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Centered thumbnails [PRO VERSION]', 'wc_svi'),
            'desc' => __('Start in center position or aligned to main image.', 'wc_svi'),
        ),
        array(
            'id' => 'notice34',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Tranisition effect [PRO VERSION]', 'wc_svi'),
            'desc' => __('Could be "slide", "fade", "cube", "coverflow" or "flip". <br><b>Note:</b> Cube transition requires that all images are of the same size, which means its width and height should be equal.', 'wc_svi'),
        ),
        array(
            'id' => 'notice35',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('LazyLoad [PRO VERSION]', 'wc_svi'),
            'desc' => __('Activates LazyLoad of images.', 'wc_svi'),
        ),
        array(
            'id' => 'notice36',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('LazyLoad Color [PRO VERSION]', 'wc_svi'),
            'desc' => __('Pick a color for the lazyload.', 'wc_svi'),
        ),
        array(
            'id' => 'notice37',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Pagination [PRO VERSION]', 'wc_svi'),
            'desc' => __('Activates pagination options.', 'wc_svi'),

        ),
        array(
            'id' => 'notice38',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Pagination Type [PRO VERSION]', 'wc_svi'),
            'desc' => __('String with type of pagination. Can be "bullets", "fraction", "progressbar".', 'wc_svi'),
        ),
        array(
            'id' => 'notice39',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Clickable Bullets [PRO VERSION]', 'wc_svi'),
            'desc' => __('If true then clicking on pagination button will cause transition to appropriate slide. Only for bullets pagination type.', 'wc_svi'),
        ),
        array(
            'id' => 'notice40',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Dynamic Bullets [PRO VERSION]', 'wc_svi'),
            'desc' => __('Good to enable if you use bullets pagination with a lot of slides. So it will keep only few bullets visible at the same time.', 'wc_svi'),
        ),
        array(
            'id' => 'notice41',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Pagination Color [PRO VERSION]', 'wc_svi'),
            'desc' => __('Pick a color for the pagination.', 'wc_svi'),
        ),
        array(
            'id' => 'notice42',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Main Navigation [PRO VERSION]', 'wc_svi'),
            'subtitle' => __('Add arrow navigation to main image.', 'wc_svi'),
        ),
        array(
            'id' => 'notice43',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Thumb Navigation [PRO VERSION]', 'wc_svi'),
            'subtitle' => __('Add arrow navigation to thumbnails.', 'wc_svi'),
        ),
        array(
            'id' => 'notice44',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Nav Color [PRO VERSION]', 'wc_svi'),
            //'subtitle' => __('Select your navigation color', 'wc_svi'),
            'desc' => __('Select your navigation color. Requires Main Navigation or Thumb navigation On.', 'wc_svi'),
        ),
        array(
            'id' => 'notice45',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Arrows Color [PRO VERSION]', 'wc_svi'),
            'desc' => __('Pick a color for the pagination.', 'wc_svi'),
        ),
        array(
            'id' => 'notice46',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Auto Slide [PRO VERSION]', 'wc_svi'),
            'subtitle' => __('Add auto sliding.', 'wc_svi'),
        ),
        array(
            'id' => 'notice47',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Auto Slide time (ms) [PRO VERSION]', 'wc_svi'),
            'desc' => __('Delay between transitions (in ms). If this parameter is not specified or is 0(zero), auto play will be 2500 (2, 5s)', 'wc_svi'),
        ),
        array(
            'id' => 'notice48',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Disable on Interaction [PRO VERSION]', 'wc_svi'),
            'desc' => __('Set to Enabled and autoplay will be disabled after user interacts.', 'wc_svi'),
        ),
    ),
));
/** LENS */
Redux::setSection($opt_name, array(
    'title' => __('Magnifier Lens', 'wc_svi'),
    'id' => 'lens-section',
    'fields' => array(
        array(
            'id' => 'lens',
            'type' => 'switch',
            'required' => array('default', '=', '1'),
            'title' => __('Activate Magnifier Lens', 'wc_svi'),
            //'subtitle' => __('Also called a "fold" parent.', 'wc_svi'),
            //'desc' => __('Disabled on mobile phones.', 'wc_svi'),
            'default' => false,
        ),
        array(
            'id' => 'notice49',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Mobile Enabled [PRO VERSION]', 'wc_svi'),
            'desc' => __('<b>NOTE</b>: I recommend this option be off, doesnt make sense in mobile since the finger will be over the lens execpt for inner. Lens is Unvailable for "Window" Zoom type. Lightbox will not work with this option enabled in Mobile View due to the trigger.', 'wc_svi'),
        ),
        array(
            'id' => 'notice50',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Zoom Type [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice51',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Disable Lens Zoom Contain [PRO VERSION]', 'wc_svi'),
            'desc' => __('NOTE: If active in some themes this option may not work properly.', 'wc_svi'),
        ),
        array(
            'id' => 'notice52',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Lens Format [PRO VERSION]', 'wc_svi'),
            'desc' => __('Select the format of the lens either square or circle.',  'wc_svi'),
        ),
        array(
            'id' => 'notice53',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Fade In Effect [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice54',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Lens FadeIn ms [PRO VERSION]', 'wc_svi'),
            'desc' => __('Set as a number e.g 200 for speed of Lens fadeIn', 'wc_svi'),
        ),
        array(
            'id' => 'notice55',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Window Fade In Effect [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice56',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Window FadeIn ms [PRO VERSION]', 'wc_svi'),
            'desc' => __('Set as a number e.g 200 for speed of Window fadeIn', 'wc_svi'),
        ),
        array(
            'id' => 'notice57',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Lens Size [PRO VERSION]', 'wc_svi'),
            'desc' => __('Lens size to be displayed, min:100 | max: 300.', 'wc_svi'),
        ),
        array(
            'id' => 'notice58',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Lens Easing [PRO VERSION]', 'wc_svi'),
            'desc' => __('Allows smooth scrool of image to Zoom Type Window & Inner', 'wc_svi'),
        ),
        array(
            'id' => 'notice59',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Magnifier Border Color [PRO VERSION]', 'wc_svi'),
            'desc' => __('Pick a border color for the lens.', 'wc_svi'),
        ),
        array(
            'id' => 'notice60',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Lens Border Width [PRO VERSION]', 'wc_svi'),
            'desc' => __('Width in pixels of the lens border. min: 1 | max: 15.', 'wc_svi'),
        ),
        array(
            'id' => 'notice61',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Width of the Window [PRO VERSION]', 'wc_svi'),
            'desc' => __('Set Width for window, default 400.', 'wc_svi'),
        ),
        array(
            'id' => 'notice62',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Height of the Window [PRO VERSION]', 'wc_svi'),
            'desc' => __('Set Height for window, default 400.', 'wc_svi'),
        ),

        array(
            'id' => 'notice63',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Zoom Effect [PRO VERSION]', 'wc_svi'),
            'desc' => __('Allows Zoom with mouse scroll.', 'wc_svi'),
        ),
        array(
            'id' => 'notice64',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Custom zIndex for Magnifier [PRO VERSION]', 'wc_svi'),
        ),
    ),
));

/** VIDEO */
Redux::setSection($opt_name, array(
    'title' => __('Video', 'wc_svi'),
    'id' => 'video-section',
    'fields' => array(
        array(
            'id' => 'notice64',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Activate Video Support [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice65',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('UI color [PRO VERSION]', 'wc_svi'),
        ),
        array(
            'id' => 'notice66',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Autoplay [PRO VERSION]', 'wc_svi'),
            'desc' => __('Autoplay the media on load.<br> Autoplay is generally not recommended as it is seen as a negative user experience. It is also disabled in many browsers. Before raising issues, do your homework. More info can be found here:
                    <ul><li><a target="_blank" href="https://webkit.org/blog/6784/new-video-policies-for-ios/">New </video> Policies for iOS</a></li>
                    <li><a target="_blank" href="https://developers.google.com/web/updates/2017/09/autoplay-policy-changes">Autoplay Policy Changes</a></li>
                    <li><a target="_blank" href="https://hacks.mozilla.org/2019/02/firefox-66-to-block-automatically-playing-audible-video-and-audio/">Firefox 66 to block automatically playing audible video and audio</a></li></ul>', 'wc_svi'),
        ),
        array(
            'id' => 'notice67',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Muted [PRO VERSION]', 'wc_svi'),
            'desc' => __('Whether to start playback muted.', 'wc_svi'),
        ),
        array(
            'id' => 'notice68',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Click To Play [PRO VERSION]', 'wc_svi'),
            'desc' => __('Click (or tap) of the video container will toggle play/pause.', 'wc_svi'),
        ),
        array(
            'id' => 'notice69',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Disable Context Menu [PRO VERSION]', 'wc_svi'),
            'desc' => __('Disable right click menu on video to help as very primitive obfuscation to prevent downloads of content.', 'wc_svi'),
        ),
        array(
            'id' => 'notice70',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Auto Hide Controls [PRO VERSION]', 'wc_svi'),
            'desc' => __('Hide video controls automatically after 2s of no mouse or focus movement, on control element blur (tab out), on playback start or entering fullscreen. As soon as the mouse is moved, a control element is focused or playback is paused, the controls reappear instantly.', 'wc_svi'),
        ),
        array(
            'id' => 'notice71',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Fullscreen [PRO VERSION]', 'wc_svi'),
            'desc' => __('Toggles whether fullscreen should be enabled on double touch/click.', 'wc_svi'),
        ),
        array(
            'id' => 'notice72',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Loop [PRO VERSION]', 'wc_svi'),
            'desc' => __('Whether to loop the current video.', 'wc_svi'),
        ),
        array(
            'id' => 'notice73',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Poster [PRO VERSION]', 'wc_svi'),
            'desc' => __('Sets SVI image as the current poster image for the player.', 'wc_svi'),
        ),
        array(
            'id' => 'notice74',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Ratio [PRO VERSION]', 'wc_svi'),
            'desc' => __('Whether to loop the current video.', 'wc_svi'),
        ),
        array(
            'id' => 'notice75',
            'type' => 'info',
            'style' => 'warning [PRO VERSION]',
            'title' => __('Video Controls', 'wc_svi'),
            'desc' =>  __('The large play button in the center', 'wc_svi') . '<br>' . __('Play/pause playback', 'wc_svi') . '<br>' . __('The progress bar and scrubber for playback and buffering', 'wc_svi') . '<br>' . __('The current time of playback', 'wc_svi') . '<br>' . __('The full duration of the media', 'wc_svi') . '<br>' . __('Toggle mute', 'wc_svi') . '<br>' . __('Volume control', 'wc_svi') . '<br>' . __('Toggle fullscreen', 'wc_svi') // Toggle fullscreen
        ),

    )
));
/** THUMBNAILS SECTION */
Redux::setSection($opt_name, array(
    'title' => __('Thumbails', 'wc_svi'),
    'id' => 'thumbnails-section',
    //'desc' => __('For full documentation on validation, visit: ', 'wc_svi') . '<a href="//docs.reduxframework.com/core/the-basics/required/" target="_blank">docs.reduxframework.com/core/the-basics/required/</a>',
    'fields' => array(
        array(
            'id' => 'notice76',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Disabled [PRO VERSION]', 'wc_svi'),
            'desc' => __('Disable thumbnails on product page', 'wc_svi'),
        ),
        array(
            'id' => 'notice77',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Position [PRO VERSION]', 'wc_svi'),
            'subtitle' => __('Select thumnails position. Bottom, Left or right.', 'wc_svi'),
            'desc' => __('Bottom, Left and Right positions, for thumbnails.', 'wc_svi'),
        ),
        array(
            'id' => 'columns',
            'type' => 'text',

            'title' => __('Items per row', 'wc_svi'),
            'desc' => __('Number of thumbnails to be displayed by row, min:1 | max: 10. <br><b>Note:</b> In PRO VERSION if using slider you may add decimal to display part of next slide, ex: 4.5', 'wc_svi'),
            //'validate' => 'numeric',
            'default' => '4',
            'validate_callback' => 'svipro_numbervalid_thumbnails',
            'required' => array(
                array('default', '=', '1'),
            ),
        ),
        array(
            'id' => 'hide_thumbs',
            'type' => 'switch',
            'title' => __('Hidden', 'wc_svi'),
            'desc' => __('Thumbnails will be hidden until a variation as been selected.<br><b>Note</b>: Will not work with products that have "<u>SVI Default Gallery</u>" present.', 'wc_svi'),
            'default' => false,
            'required' => array(
                array('default', '=', '1'),
            ),
        ),
        array(
            'id' => 'notice78',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Trigger on Thumbnail click [PRO VERSION]', 'wc_svi'),
            'subtitle' => __('Change value of the attributes/Swatches', 'wc_svi'),
            'desc' => __('<ul><li>When user clicks the thumbnail the values of Attributes/Swatches will changed to reflect the image values.</li><li>If image is present in multiple SVI Galleries the Variations/Swatches will be changed to the first match.</li></ul>', 'wc_svi'),
        ),
        array(
            'id' => 'notice79',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Keep visible [PRO VERSION]', 'wc_svi'),
            'desc' => __('This option will keep thumbnails visible all the time. <b>No changes</b> will be made to the product gallery.<br> Option should be disabled if "Showcase Images under Variations" is active or may cause unexpected behaviour.', 'wc_svi'),
        ),
        array(
            'id' => 'notice80',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Default Display [PRO VERSION]', 'wc_svi'),
            'desc' => __('Select the default display to be showed.<br>If <b>SVI Default Gallery</b> not present it will fallback to WooCommerce Product Gallery.', 'wc_svi'),
        ),
        array(
            'id' => 'notice81',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Thumbnail Opacity [PRO VERSION]', 'wc_svi'),
            'desc' => __('If active, current tumbnail will be faded.', 'wc_svi'),
        ),
    ),
));
/** LAYOUT FIXES */
Redux::setSection($opt_name, array(
    'title' => __('Layout Fixes', 'wc_svi'),
    'id' => 'fixes-subsection',
    //'desc' => __('For full documentation on validation, visit: ', 'wc_svi') . '<a href="//docs.reduxframework.com/core/the-basics/required/" target="_blank">docs.reduxframework.com/core/the-basics/required/</a>',
    'fields' => array(
        array(
            'id' => 'notice82',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Custom Class [PRO VERSION]', 'wc_svi'),
            'desc' => __('Insert custom css class(es) to fit your theme needs.', 'wc_svi'),
        ),
        array(
            'id' => 'notice83',
            'type' => 'info',
            'style' => 'warning',
            'title' => __('Remove Image class [PRO VERSION]', 'wc_svi'),
            'desc' => __('Some theme force styling on image class that may break the layout.', 'wc_svi'),
        )
    ),
));




/*
 * <--- END SECTIONS
 */


if (!function_exists('svipro_numbervalid_thumbnails')) :

    function svipro_numbervalid_thumbnails($field, $value, $existing_value)
    {
        $return['value'] = $existing_value;
        if (is_numeric($value)) {
            if ($value !== $existing_value || intval($value) > 10) {
                if (intval($value) < 1 || intval($value) > 10) {
                    $return['value'] = 4;
                    $field['msg'] = 'Minimum 1 thumbnail per row, Max 10 Thumbnails per row.';
                    $return['error'] = $field;
                } else {
                    $return['value'] = $value;
                }
            }
        } else {
            $return['value'] = 4;
            $field['msg'] = 'Please insert a number between 1 and 10.';
            $return['error'] = $field;
        }

        return $return;
    }

endif;
